@@ -298,7 +298,7 @@ basetemplates.HTMLPageHeader.css = {
     "breadcrumbs": "cw-breadcrumb",
     "container-cls": basetemplates.TheMainTemplate.twbs_container_cls,
     "header-left": "",
-    "header-right": "navbar-right",
+    "header-right": "d-flex justify-content-end align-items-center m-2 navbar-right list-unstyled",
 }
 
 
@@ -337,7 +337,7 @@ basetemplates.HTMLPageHeader.display_navbar_header = display_navbar_header
 def display_header_components(self, w, view, context):
     components = self.get_components(view, context=context)
     if components:
-        w('<ul class="nav navbar-nav %s">' % self.css[context])
+        w('<ul class="%s">' % self.css[context])
         for component in components:
             w("<li>")
             component.render(w=w)
